====
pyqa
====


.. image:: https://img.shields.io/pypi/v/pyqa.svg
        :target: https://pypi.python.org/pypi/pyqa

.. image:: https://img.shields.io/travis/yusufadell/pyqa.svg
        :target: https://travis-ci.com/yusufadell/pyqa

.. image:: https://readthedocs.org/projects/pyqa/badge/?version=latest
        :target: https://pyqa.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python console appliction that searches the internet for asnwers to coding problems


* Free software: Apache Software License 2.0
* Documentation: https://pyqa.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
